# GRID 
grid.props =
	image: "images/gridlines.png"
	style:
		backgroundPosition: "0px 0px"
		backgroundRepeat: "repeat"
		backgroundSize: "auto"

# VARIABLES
curves = [
	{
		curve: Bezier.linear
		name: "Bezier.linear"
	}
	{
		curve: Bezier.easeIn
		name: "Bezier.easeIn"
	}
	{
		curve: Bezier.easeOut
		name: "Bezier.easeOut"
	}
	{
		curve: Bezier.ease
		name: "Bezier.ease"
	}
	{
		curve: Bezier.easeInOut
		name: "Bezier.easeInOut"
	}
	{
		curve: Bezier( 1, -0.65, 0, 1.25 )
		name: "Bezier( 1, -0.65, 0, 1.25 )"
	}
	{
		curve: Spring
		name: "Spring"
	}
]
curve_layer_A = curves[0]
curve_layer_B = curves[3]

# ANIMATIONS
createAndTriggerAnimations = ->
	# stop any running animations
	layerA.animateStop()
	layerB.animateStop()
	
	# delete all existing animations
	goLeftLayerA = null
	goRightLayerA = null
	goLeftLayerB = null
	goRightLayerB = null
	
	# set to start position
	layerA.x = 20
	layerB.x = 20
	
	# recreate animations
	goLeftLayerA = new Animation layerA,
		maxX: grid.width - 20
		options:
			curve: curve_layer_A.curve
			time: 2
			delay: 0.5
	
	goRightLayerA = new Animation layerA,
		x: 20
		options:
			curve: curve_layer_A.curve
			time: 2
			delay: 0.5
	
	goLeftLayerB = new Animation layerB,
		maxX: grid.width - 20
		options:
			curve: curve_layer_B.curve
			time: 2
			delay: 0.5

	goRightLayerB = new Animation layerB,
		x: 20
		options:
			curve: curve_layer_B.curve
			time: 2
			delay: 0.5
	
	# go right after going left
	goLeftLayerA.onAnimationEnd ->
		goRightLayerA.start()
		goRightLayerB.start()
	
	# and back left when at start position
	goRightLayerA.onAnimationEnd ->
		goLeftLayerA.start()
		goLeftLayerB.start()
	
	goLeftLayerA.start()
	goLeftLayerB.start()

# Animation curve for Layer A
curve_layer_A_title = new TextLayer
	x: 50
	y: grid.maxY + 25
	text: "Animation curve for Layer A"
	color: "#fff"
	fontFamily: Title.fontFamily
	fontWeight: 300
	fontSize: 28

dot_1 = new Layer
dot_2 = new Layer
dot_3 = new Layer
dot_4 = new Layer
dot_5 = new Layer
dot_6 = new Layer
dot_7 = new Layer

dots_A = [dot_1, dot_2, dot_3, dot_4, dot_5, dot_6, dot_7]

# Loop over the dots
for dot, i in dots_A
	white_dot = new Layer
		size: 30
		borderRadius: 15
		backgroundColor: "#fff"
		x: curve_layer_A_title.x + 5
		y: curve_layer_A_title.maxY + 20 + (i*44)
	
	dot.props =
		size: 20
		borderRadius: 10
		backgroundColor: "#28AFFA"
		point: 5
		parent: white_dot
	
	dot.states.hidden =
		opacity: 0
	dot.animationOptions =
		time: .5
	
	if curves[i] isnt curve_layer_A
		dot.stateSwitch "hidden"
	
	label = new TextLayer
		x: curve_layer_A_title.x
		y: white_dot.y + 2
		text: curves[i].name
		color: "#fff"
		name: "A"+i
		fontFamily: "Menlo,Monaco,Courier,monospace"
		fontSize: 18
		padding:
			left: 50
	
	label.onTap ->
		for dot, i in dots_A
			if "#{i}" is @name.substring 1, 2
				dot.animate "default"
			else
				dot.animate "hidden"
		
		curve_layer_A = curves[@name.substring 1, 2]
		createAndTriggerAnimations()

# Animation curve for Layer B
curve_layer_B_title = new TextLayer
	x: grid.midX + 50
	y: grid.maxY + 25
	text: "Animation curve for Layer B"
	color: "#fff"
	fontFamily: Title.fontFamily
	fontWeight: 300
	fontSize: 28

dot_8 = new Layer
dot_9 = new Layer
dot_10 = new Layer
dot_11 = new Layer
dot_12 = new Layer
dot_13 = new Layer
dot_14 = new Layer

dots_B = [dot_8, dot_9, dot_10, dot_11, dot_12, dot_13, dot_14]

# Loop over the dots
for dot, i in dots_B
	white_dot = new Layer
		size: 30
		borderRadius: 15
		backgroundColor: "#fff"
		x: curve_layer_B_title.x + 5
		y: curve_layer_B_title.maxY + 20 + (i*44)
	
	dot.props =
		size: 20
		borderRadius: 10
		backgroundColor: "#7DDD11"
		point: 5
		parent: white_dot
	
	dot.states.hidden =
		opacity: 0
	dot.animationOptions =
		time: .5
	
	if curves[i] isnt curve_layer_B
		dot.stateSwitch "hidden"
	
	label = new TextLayer
		x: curve_layer_B_title.x
		y: white_dot.y + 2
		text: curves[i].name
		color: "#fff"
		name: "B"+i
		fontFamily: "Menlo,Monaco,Courier,monospace"
		fontSize: 18
		padding:
			left: 50
	
	label.onTap ->
		for dot, i in dots_B
			if "#{i}" is @name.substring 1, 2
				dot.animate "default"
			else
				dot.animate "hidden"
		
		curve_layer_B = curves[@name.substring 1, 2]
		createAndTriggerAnimations()

# AFTER LOADING
createAndTriggerAnimations()